.. Spiker documentation master file, created by
   sphinx-quickstart on Fri Feb 12 09:49:01 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Spiker's Documentation
======================

.. toctree::
   :caption: Introduction
   
   introduction

.. toctree::
   :caption: Installation
   :numbered:
   :maxdepth: 2

   installation


.. toctree::
   :caption: Usage information
   :numbered:
   :maxdepth: 2
   
   usage


.. toctree::
   :caption: Walkthrough example
   :numbered:
   :maxdepth: 2
   
   walkthrough


.. toctree::
   :caption: Bowtie2 Index Files
   :numbered:
   :maxdepth: 2   

   bowtie2_index


.. toctree::
   :caption: Test Dataset
   :numbered:
   :maxdepth: 2
   
   dataset
   
.. toctree::
   :caption: Release history
   :numbered:
   :maxdepth: 2

   change_log


.. toctree::
   :caption: Liscense

   liscense
